whenAvailable("jQuery", function ($) {
    $(document).ready(function () {
        addDefaultValidators();
        addCnpjServerValidator();
        addCpfServerValidator();
        if ($("#MessagePanel.alert-danger").text().contains("CNPJ já existe")) { $("#MessagePanel.alert-danger").html("<span class=\"fa fa-exclamation-triangle\" aria-hidden=\"true\"></span>&nbspJá existe empresa com o CNPJ informado.") }
        if ($("#MessagePanel.alert-danger").text().contains("CPF já existe")) { $("#MessagePanel.alert-danger").html("<span class=\"fa fa-exclamation-triangle\" aria-hidden=\"true\"></span>&nbspJá existe cadastro para o CPF informado.") }
    });   

});

function addDefaultValidators() {
    var SPMaskBehavior = function (val) {
        return val.replace(/\D/g, '').length === 11 ? '(00) 00000-0000' : '(00) 0000-00009';
    },
        spOptions = {
            onKeyPress: function (val, e, field, options) {
                field.mask(SPMaskBehavior.apply({}, arguments), options);
            }
        };

    $('#telephone1').mask(SPMaskBehavior, spOptions);
    $('#mobilephone').mask(SPMaskBehavior, spOptions);    
    $('#telephone3').mask(SPMaskBehavior, spOptions);    
    $('#k2m_cnpj').mask('00.000.000/0000-00', { reverse: true });
    $('#k2m_cpf').mask('000.000.000-00', { reverse: true });
    $('#address1_postalcode').mask('00000-000', { reverse: true });
    $('#address1_postalcode').blur(function (e) {
        pesquisarCep(e.target.value);
    });

}

function addCpfServerValidator() {

    if ($("#k2m_cpf").length == 0)
    {
        return;
    }
    if (typeof (Page_Validators) == 'undefined') return;
    // Create new validator
    var newValidator = document.createElement('span');
    newValidator.style.display = "none";
    newValidator.id = "k2m_cpf";
    newValidator.controltovalidate = "k2m_cpf";
    newValidator.errormessage = "<a href='#k2m_cpf_label'>CPF inválido.</a>";
    newValidator.validationGroup = ""; // Set this if you have set ValidationGroup on the form
    newValidator.initialvalue = "";
    newValidator.evaluationfunction = function () {
        var cpf = $("#k2m_cpf").val();        
        return validarCPF(cpf);
    };

    // Add the new validator to the page validators array:
    Page_Validators.push(newValidator);
    // Wire-up the click event handler of the validation summary link
    $("a[href='#k2m_cpf_label']").on("click", function () { scrollToAndFocus('k2m_cpf_label', 'k2m_cpf'); });

}


function addCnpjServerValidator() {

    if ($("#k2m_cnpj").length == 0)
    {
        return;
    }
    if (typeof (Page_Validators) == 'undefined') return;
    // Create new validator
    var newValidator = document.createElement('span');
    newValidator.style.display = "none";
    newValidator.id = "k2m_cnpj";
    newValidator.controltovalidate = "k2m_cnpj";
    newValidator.errormessage = "<a href='#k2m_cnpj_label'>CNPJ inválido.</a>";
    newValidator.validationGroup = ""; // Set this if you have set ValidationGroup on the form
    newValidator.initialvalue = "";
    newValidator.evaluationfunction = function () {
        var cnpj = $("#k2m_cnpj").val();        
        return validarCNPJ(cnpj);
    };

    // Add the new validator to the page validators array:
    Page_Validators.push(newValidator);
    // Wire-up the click event handler of the validation summary link
    $("a[href='#k2m_cnpj_label']").on("click", function () { scrollToAndFocus('k2m_cnpj_label', 'k2m_cnpj'); });

}

function validarCPF(cpf) {
    strCPF = cpf.replace(/[^\d]+/g, '');
    var Soma;
    var Resto;
    Soma = 0;
    if (strCPF == "00000000000") return false;

    for (i = 1; i <= 9; i++) Soma = Soma + parseInt(strCPF.substring(i - 1, i)) * (11 - i);
    Resto = (Soma * 10) % 11;

    if ((Resto == 10) || (Resto == 11)) Resto = 0;
    if (Resto != parseInt(strCPF.substring(9, 10))) return false;

    Soma = 0;
    for (i = 1; i <= 10; i++) Soma = Soma + parseInt(strCPF.substring(i - 1, i)) * (12 - i);
    Resto = (Soma * 10) % 11;

    if ((Resto == 10) || (Resto == 11)) Resto = 0;
    if (Resto != parseInt(strCPF.substring(10, 11))) return false;
    return true;

}

function validarCNPJ(cnpj) {

    cnpj = cnpj.replace(/[^\d]+/g, '');

    if (cnpj == '') return false;

    if (cnpj.length != 14)
        return false;

    // Elimina CNPJs invalidos conhecidos
    if (cnpj == "00000000000000" ||
        cnpj == "11111111111111" ||
        cnpj == "22222222222222" ||
        cnpj == "33333333333333" ||
        cnpj == "44444444444444" ||
        cnpj == "55555555555555" ||
        cnpj == "66666666666666" ||
        cnpj == "77777777777777" ||
        cnpj == "88888888888888" ||
        cnpj == "99999999999999")
        return false;

    // Valida DVs
    tamanho = cnpj.length - 2
    numeros = cnpj.substring(0, tamanho);
    digitos = cnpj.substring(tamanho);
    soma = 0;
    pos = tamanho - 7;
    for (i = tamanho; i >= 1; i--) {
        soma += numeros.charAt(tamanho - i) * pos--;
        if (pos < 2)
            pos = 9;
    }
    resultado = soma % 11 < 2 ? 0 : 11 - soma % 11;
    if (resultado != digitos.charAt(0))
        return false;

    tamanho = tamanho + 1;
    numeros = cnpj.substring(0, tamanho);
    soma = 0;
    pos = tamanho - 7;
    for (i = tamanho; i >= 1; i--) {
        soma += numeros.charAt(tamanho - i) * pos--;
        if (pos < 2)
            pos = 9;
    }
    resultado = soma % 11 < 2 ? 0 : 11 - soma % 11;
    if (resultado != digitos.charAt(1))
        return false;

    return true;

}


function pesquisarCep(valor) {

    //Nova variável "cep" somente com dígitos.
    var cep = valor.replace(/\D/g, '');

    //Verifica se campo cep possui valor informado.
    if (cep != "") {

        //Expressão regular para validar o CEP.
        var validacep = /^[0-9]{8}$/;

        //Valida o formato do CEP.
        if (validacep.test(cep)) {


            fetch('https://viacep.com.br/ws/' + cep + '/json')
                .then(function (resp) { return resp.json() })
                .then(function (data) {
                    document.getElementById('address1_line1').value = data.logradouro;
                    document.getElementById('address1_line3').value = data.bairro;
                    document.getElementById('address1_city').value = data.localidade;
                    document.getElementById('address1_stateorprovince').value = data.uf;
                });

        }
    }
};
